# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 6.0.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from empire_platform_api_public_client.api.finance_api import FinanceApi


class TestFinanceApi(unittest.TestCase):
    """FinanceApi unit test stubs"""

    def setUp(self) -> None:
        self.api = FinanceApi()

    def tearDown(self) -> None:
        pass

    def test_download_all_finance_invoice_group_pdfs(self) -> None:
        """Test case for download_all_finance_invoice_group_pdfs

        """
        pass

    def test_get_finance_invoice(self) -> None:
        """Test case for get_finance_invoice

        """
        pass

    def test_get_finance_invoices(self) -> None:
        """Test case for get_finance_invoices

        """
        pass

    def test_get_finance_settlement_per_day(self) -> None:
        """Test case for get_finance_settlement_per_day

        """
        pass

    def test_get_finance_settlement_per_source(self) -> None:
        """Test case for get_finance_settlement_per_source

        """
        pass

    def test_get_finance_uiosi_overview(self) -> None:
        """Test case for get_finance_uiosi_overview

        """
        pass


if __name__ == '__main__':
    unittest.main()
